@@ -13,7 +13,7 @@ from axes.helpers import (
     get_failure_limit,
 )
 
-log = getLogger(settings.AXES_LOGGER)
+log = getLogger(__name__)
 
 
 class AxesCacheHandler(AbstractAxesHandler, AxesBaseHandler):
@@ -48,6 +48,12 @@ class AxesCacheHandler(AbstractAxesHandler, AxesBaseHandler):
             return
 
         username = get_client_username(request, credentials)
+        if settings.AXES_ONLY_USER_FAILURES and username is None:
+            log.warning(
+                "AXES: Username is None and AXES_ONLY_USER_FAILURES is enable, New record won't be created."
+            )
+            return
+
         client_str = get_client_str(
             username,
             request.axes_ip_address,
