@@ -1,5 +1,6 @@
 from unittest.mock import MagicMock, patch
 
+from django.core.cache import cache
 from django.test import override_settings
 from django.urls import reverse
 from django.utils import timezone
@@ -260,6 +261,25 @@ class AxesDatabaseHandlerTestCase(AxesHandlerBaseTestCase):
     def test_whitelist(self, log):
         self.check_whitelist(log)
 
+    @patch("axes.handlers.database.log")
+    def test_user_login_failed_only_user_failures_with_none_username(self, log):
+        with self.settings(**{"AXES_ONLY_USER_FAILURES": True}):
+            credentials = {"username": None, "password": "test"}
+            sender = MagicMock()
+            AxesProxyHandler.user_login_failed(sender, credentials, self.request)
+            attempt = AccessAttempt.objects.all()
+            self.assertEqual(0, AccessAttempt.objects.count())
+        log.warning.assert_called_with(
+            "AXES: Username is None and AXES_ONLY_USER_FAILURES is enable, New record won't be created."
+        )
+
+    def test_user_login_failed_with_none_username(self):
+        credentials = {"username": None, "password": "test"}
+        sender = MagicMock()
+        AxesProxyHandler.user_login_failed(sender, credentials, self.request)
+        attempt = AccessAttempt.objects.all()
+        self.assertEqual(1, AccessAttempt.objects.filter(username__isnull=True).count())
+
     def test_user_login_failed_multiple_username(self):
         configurations = (
             (2, 1, {}, ["admin", "admin1"]),
@@ -335,6 +355,27 @@ class AxesCacheHandlerTestCase(AxesHandlerBaseTestCase):
     def test_whitelist(self, log):
         self.check_whitelist(log)
 
+    @patch.object(cache, "set")
+    @patch("axes.handlers.cache.log")
+    def test_user_login_failed_only_user_failures_with_none_username(
+        self, log, cache_set
+    ):
+        with self.settings(**{"AXES_ONLY_USER_FAILURES": True}):
+            credentials = {"username": None, "password": "test"}
+            sender = MagicMock()
+            AxesProxyHandler.user_login_failed(sender, credentials, self.request)
+        self.assertFalse(cache_set.called)
+        log.warning.assert_called_with(
+            "AXES: Username is None and AXES_ONLY_USER_FAILURES is enable, New record won't be created."
+        )
+
+    @patch.object(cache, "set")
+    def test_user_login_failed_with_none_username(self, cache_set):
+        credentials = {"username": None, "password": "test"}
+        sender = MagicMock()
+        AxesProxyHandler.user_login_failed(sender, credentials, self.request)
+        self.assertTrue(cache_set.called)
+
 
 @override_settings(AXES_HANDLER="axes.handlers.dummy.AxesDummyHandler")
 class AxesDummyHandlerTestCase(AxesHandlerBaseTestCase):
