@@ -1,4 +1,8 @@
+from unittest import mock
+
 from django.http import HttpResponse, HttpRequest
+from django.conf import settings
+from django.test import override_settings
 
 from axes.middleware import AxesMiddleware
 from axes.tests.base import AxesTestCase
@@ -26,3 +30,12 @@ class MiddlewareTestCase(AxesTestCase):
 
         response = AxesMiddleware(get_response)(self.request)
         self.assertEqual(response.status_code, self.STATUS_LOCKOUT)
+
+    @override_settings(AXES_ENABLED=False)
+    def test_respects_enabled_switch(self):
+        def get_response(request):
+            request.axes_locked_out = True
+            return HttpResponse()
+
+        response = AxesMiddleware(get_response)(self.request)
+        self.assertEqual(response.status_code, self.STATUS_SUCCESS)
